@@ -6,7 +6,8 @@ library("matrixStats")
 set.seed(1)
 
 cat("Consistency checks:\n")
-for (kk in 1:20) {
+K <- if (Sys.getenv("_R_CHECK_FULL_") == "") 2 else 20;
+for (kk in 1:K) {
   cat("Random test #", kk, "\n", sep="")
 
   # Simulate data in a matrix of any shape
@@ -20,13 +21,13 @@ for (kk in 1:20) {
   if (nas) {
     cat("Adding NAs\n");
     nna <- sample(n, size=1)
-    naValues <- c(as.double(NA), NaN);
+    naValues <- c(as.double(NA), NaN)
     x[sample(length(x), size=nna)] <- sample(naValues, size=nna, replace=TRUE)
   }
 
   # Integer or double?
   if (sample(c(TRUE,FALSE), size=1)) {
-    cat("Coercing to integers\n");
+    cat("Coercing to integers\n")
     storage.mode(x) <- c("integer")
   }
 
